from distillation.semiSupervised import *

__all__=[pureDistillation,dataDistillation,modelDistillation,modelDataDistillation]

pureDistillation.__module__='distillation'
dataDistillation.__module__='distillation'
modelDistillation.__module__='distillation'
modelDataDistillation.__module__='distillation'